@@ -44,6 +44,7 @@ unsigned Bayonne::compile_count;
 volatile bool Bayonne::image_loaded = false;
 bool Bayonne::provision_system = false;
 bool Bayonne::provision_user = false;
+const char *Bayonne::provision_server = "bayonne";
 
 Audio::Encoding Bayonne::peer_encoding = Audio::unknownEncoding;
 Audio::timeout_t Bayonne::peer_framing = 0;
@@ -88,6 +89,20 @@ Bayonne::statetab Bayonne::states[] = {
 	{"final", &BayonneSession::stateFinal, ' '},
 	{NULL, NULL, ' '}};
 
+const char *Bayonne::getKeypath(const char *key)
+{
+	static char keypath[128];
+
+        if(strnicmp(key + 1, "bayonne/", 8))
+                return key;
+
+        keypath[0] = *key;
+        key += 9;
+        snprintf(keypath + 1, sizeof(keypath) - 1, "%s/%s",
+                provision_server, key);
+        return keypath;
+}    
+
 void Bayonne::waitLoaded(void)
 {
 	while(!image_loaded)
