@@ -111,6 +111,7 @@ public:
 	static volatile bool image_loaded;
 	static bool provision_system;
 	static bool provision_user;
+	static const char *provision_server;
 
 	static BayonneDriver *start_driver;
 	static Audio::Encoding peer_encoding;
@@ -119,6 +120,8 @@ public:
 	static const char *init_voicelib;
 	static AtomicCounter libexec_count;
 
+	static const char *getKeypath(const char *cp);
+
 	/**
 	 * Telephony endpoint interface identifiers.
 	 */ 
