@@ -24,7 +24,7 @@ BayonneDriver *BayonneDriver::lastDriver = NULL;
 Semaphore BayonneDriver::oink(0);
 
 BayonneDriver::BayonneDriver(Keydata::Define *pairs, const char *cfg, const char *id, bool pri) :
-Keydata(pairs, cfg), Mutex()
+Keydata(pairs, getKeypath(cfg)), Mutex()
 {
 	name = id;
 	running = false;
