@@ -1385,12 +1385,19 @@ attach:
 			switch(type)
 			{
 			case DIRECT:
+				type = INCOMING;
 				if(cinfo && *cinfo)
 				{
 					snprintf(buf, sizeof(buf), "info:%s", cinfo);
-					scriptEvent(buf);
+					if(scriptEvent(buf))
+						break;	
+				}
+				if(cid && *cid)
+				{
+					snprintf(buf, sizeof(buf), "caller:%s", cid);
+					if(digitEvent(buf))
+						break;
 				}
-				type = INCOMING;
 				break;
 			case FORWARDED:
 				if(did && *did)
