@@ -555,6 +555,7 @@ BayonneTranslator *BayonneTranslator::loadTranslator(const char *prefix, const c
         const char *cp;
         const char *path;
 	char nid[3];
+	const char *lid = id;
 
 #ifdef  WIN32
         if(!prefix)
@@ -587,10 +588,15 @@ retry:
                 id = ++cp;
         }
  
-        d = get(id);
+        d = get(lid);
         if(d)
                 return d;  
 
+	if(id[2] != lid[2])
+	d = get(id);
+	if(d)
+		return d;
+
         if(!canAccess(path))
         {
 		if(id[2] == '_')
@@ -614,5 +620,12 @@ retry:
 	                errlog("error", "%s: %s", path, dso->getError());
                 return NULL;
         }
-        return get(id);  
+        d = get(lid);  
+	if(d)
+		return d;
+
+	if(id[2] != lid[2])
+		d = get(id);
+
+	return d;
 }
