@@ -22,6 +22,70 @@ namespace server {
 using namespace ost;
 using namespace std;
 
+const char *Checks::chkConfig(Line *line, ScriptImage *img)
+{
+	Name *scr = img->getCurrent();
+	unsigned idx = 0;
+	const char *fname;
+	const char *key, *value;
+	char basename[65];
+	char buf[65];
+	char *p;
+
+	fname = strrchr(scr->filename, '/');
+	if(!fname)
+		fname = scr->filename;
+	else
+		++fname;
+	
+	if(getMember(line))
+		return "config uses no members";
+
+	if(hasKeywords(line))
+		return "keywords not used for config";
+
+	key = getOption(line, &idx);
+	if(!key)
+		return "config key missing";
+
+	value = getOption(line, &idx);
+	if(!value)
+		return "config value missing";
+
+	if(getOption(line, &idx))
+		return "too many arguments for config";
+
+	setString(basename, sizeof(basename), scr->name);
+	p = strchr(basename, ':');
+	if(p)
+		*p = 0;
+
+	if(!img->getLast(fname))
+	{
+		img->setValue(fname, "set");
+		snprintf(buf, sizeof(buf), "/bayonne/scripts/%s", fname);
+		img->loadPrefix(basename, buf);
+#ifndef	WIN32
+		if(Bayonne::provision_system)
+		{
+			snprintf(buf, sizeof(buf), "/bayonne/provision/%s", fname);
+			img->loadPrefix(basename, buf);
+		}
+		else if(Bayonne::provision_user)
+		{
+			snprintf(buf, sizeof(buf), "~bayonne/%s", fname);
+			img->loadPrefix(basename, buf);
+		}
+#endif		
+	}	
+
+	snprintf(buf, sizeof(buf), "%s.%s", basename, key);
+	if(!img->getLast(buf))
+		img->setValue(buf, value);
+
+	return "";
+}
+
 const char *Checks::chkPaths(Line *line, ScriptImage *img)
 {	
 	unsigned idx = 0;
