@@ -50,7 +50,7 @@ using namespace std;
 #endif
 
 #ifdef	WIN32
-#define	PROMPT_FILES	"C:\\Program Files\\GNU Telephony\\Bayonne Audio"
+#define	PROMPT_FILES	"C:\\Program Files\\GNU Telephony\\Phrasebook Audio"
 #define	SCRIPT_FILES	"C:\\Program Files\\GNU Telephony\\Bayonne Scripts"
 #define	MACRO_FILES	"C:\\Program Files\\GNU Telephony\\Bayonne Macros"
 #define	VAR_FILES	"C:\\Program Files\\GNU Telephony\\Bayonne Files"
